@@ -31,12 +31,15 @@ __all__ = (
     "GroupTypeDef",
     "MailboxExportJobTypeDef",
     "MemberTypeDef",
+    "MobileDeviceAccessMatchedRuleTypeDef",
+    "MobileDeviceAccessRuleTypeDef",
     "OrganizationSummaryTypeDef",
     "PermissionTypeDef",
     "ResourceTypeDef",
     "TagTypeDef",
     "UserTypeDef",
     "CreateGroupResponseTypeDef",
+    "CreateMobileDeviceAccessRuleResponseTypeDef",
     "CreateOrganizationResponseTypeDef",
     "CreateResourceResponseTypeDef",
     "CreateUserResponseTypeDef",
@@ -50,12 +53,14 @@ __all__ = (
     "GetAccessControlEffectResponseTypeDef",
     "GetDefaultRetentionPolicyResponseTypeDef",
     "GetMailboxDetailsResponseTypeDef",
+    "GetMobileDeviceAccessEffectResponseTypeDef",
     "ListAccessControlRulesResponseTypeDef",
     "ListAliasesResponseTypeDef",
     "ListGroupMembersResponseTypeDef",
     "ListGroupsResponseTypeDef",
     "ListMailboxExportJobsResponseTypeDef",
     "ListMailboxPermissionsResponseTypeDef",
+    "ListMobileDeviceAccessRulesResponseTypeDef",
     "ListOrganizationsResponseTypeDef",
     "ListResourceDelegatesResponseTypeDef",
     "ListResourcesResponseTypeDef",
@@ -155,6 +160,33 @@ MemberTypeDef = TypedDict(
     total=False,
 )
 
+MobileDeviceAccessMatchedRuleTypeDef = TypedDict(
+    "MobileDeviceAccessMatchedRuleTypeDef",
+    {"MobileDeviceAccessRuleId": str, "Name": str},
+    total=False,
+)
+
+MobileDeviceAccessRuleTypeDef = TypedDict(
+    "MobileDeviceAccessRuleTypeDef",
+    {
+        "MobileDeviceAccessRuleId": str,
+        "Name": str,
+        "Description": str,
+        "Effect": Literal["ALLOW", "DENY"],
+        "DeviceTypes": List[str],
+        "NotDeviceTypes": List[str],
+        "DeviceModels": List[str],
+        "NotDeviceModels": List[str],
+        "DeviceOperatingSystems": List[str],
+        "NotDeviceOperatingSystems": List[str],
+        "DeviceUserAgents": List[str],
+        "NotDeviceUserAgents": List[str],
+        "DateCreated": datetime,
+        "DateModified": datetime,
+    },
+    total=False,
+)
+
 OrganizationSummaryTypeDef = TypedDict(
     "OrganizationSummaryTypeDef",
     {
@@ -209,6 +241,10 @@ UserTypeDef = TypedDict(
 
 CreateGroupResponseTypeDef = TypedDict("CreateGroupResponseTypeDef", {"GroupId": str}, total=False)
 
+CreateMobileDeviceAccessRuleResponseTypeDef = TypedDict(
+    "CreateMobileDeviceAccessRuleResponseTypeDef", {"MobileDeviceAccessRuleId": str}, total=False
+)
+
 CreateOrganizationResponseTypeDef = TypedDict(
     "CreateOrganizationResponseTypeDef", {"OrganizationId": str}, total=False
 )
@@ -324,6 +360,15 @@ GetMailboxDetailsResponseTypeDef = TypedDict(
     "GetMailboxDetailsResponseTypeDef", {"MailboxQuota": int, "MailboxSize": float}, total=False
 )
 
+GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
+    "GetMobileDeviceAccessEffectResponseTypeDef",
+    {
+        "Effect": Literal["ALLOW", "DENY"],
+        "MatchedRules": List["MobileDeviceAccessMatchedRuleTypeDef"],
+    },
+    total=False,
+)
+
 ListAccessControlRulesResponseTypeDef = TypedDict(
     "ListAccessControlRulesResponseTypeDef",
     {"Rules": List["AccessControlRuleTypeDef"]},
@@ -356,6 +401,12 @@ ListMailboxPermissionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListMobileDeviceAccessRulesResponseTypeDef = TypedDict(
+    "ListMobileDeviceAccessRulesResponseTypeDef",
+    {"Rules": List["MobileDeviceAccessRuleTypeDef"]},
+    total=False,
+)
+
 ListOrganizationsResponseTypeDef = TypedDict(
     "ListOrganizationsResponseTypeDef",
     {"OrganizationSummaries": List["OrganizationSummaryTypeDef"], "NextToken": str},
